@@ -5,9 +5,13 @@
 
 import io
 
-from .parser import HttpParser
-from .reader import HttpBodyReader
-from .util import status_reasons
+try:
+    from http_parser.parser import HttpParser
+except ImportError:
+    from http_parser.pyparser import HttpParser
+
+from http_parser.reader import HttpBodyReader
+from http_parser.util import status_reasons
 
 HTTP_BOTH = 2
 HTTP_RESPONSE = 1
